@@ -27,7 +27,7 @@ class Hesabe(object):
             decrypted = crypt.decrypt(response.text, key, iv)
             decrypted_json = json.loads(decrypted)
             payment_token = decrypted_json["response"]["data"]
-            response_data = {"payment_url": base_url+"payment?data="+payment_token}
+            response_data = {"payment_url": base_url+"/payment?data="+payment_token}
             return json.dumps(response_data)
         except:
             return {'error': "Authentication failed, please check access code"}
